--- old/usr/src/uts/common/inet/sockmods/socksctp.c	2015-08-09 12:47:58.395707031 +0300
+++ new/usr/src/uts/common/inet/sockmods/socksctp.c	2015-08-09 12:47:58.419157931 +0300
@@ -30,6 +30,7 @@
 #include <sys/buf.h>
 #include <sys/vfs.h>
 #include <sys/vnode.h>
+#include <sys/fcntl.h>
 #include <sys/debug.h>
 #include <sys/errno.h>
 #include <sys/stropts.h>
@@ -106,6 +107,8 @@
 static void sctp_assoc_xmitted(sock_upper_handle_t, boolean_t);
 static void sctp_assoc_properties(sock_upper_handle_t,
     struct sock_proto_props *);
+static conn_pid_node_list_hdr_t *
+    sctp_get_sock_pid_list(sock_upper_handle_t);
 
 sonodeops_t sosctp_sonodeops = {
 	sosctp_init,			/* sop_init	*/
@@ -168,6 +171,9 @@
 	sctp_assoc_xmitted,
 	NULL,			/* su_recv_space */
 	NULL,			/* su_signal_oob */
+	NULL,			/* su_set_error */
+	NULL,			/* su_closed */
+	sctp_get_sock_pid_list
 };
 
 /* ARGSUSED */
@@ -1773,6 +1779,11 @@
 		mutex_exit(&nfp->f_tlock);
 		setf(nfd, nfp);
 
+		/* add curproc to the pid list associated with that file */
+		if (nfp->f_vnode != NULL)
+			(void) VOP_IOCTL(nfp->f_vnode, F_FORKED,
+			    (intptr_t)curproc, FKIOCTL, kcred, NULL, NULL);
+
 		mutex_enter(&so->so_lock);
 
 		sosctp_assoc_move(ss, SOTOSSO(nso), ssa);
@@ -2230,3 +2241,17 @@
 	}
 	mutex_exit(&so->so_lock);
 }
+
+static conn_pid_node_list_hdr_t *
+sctp_get_sock_pid_list(sock_upper_handle_t handle)
+{
+	struct sctp_soassoc *ssa = (struct sctp_soassoc *)handle;
+	struct sonode *so;
+
+	if (ssa->ssa_type == SOSCTP_ASSOC)
+		so = &ssa->ssa_sonode->ss_so;
+	else
+		so = &((struct sctp_sonode *)handle)->ss_so;
+
+	return (so_get_sock_pid_list((sock_upper_handle_t)so));
+}
